<template>
  <el-dialog
    width="30%"
    top="5vh"
    title="生成任务单明细"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="generate-task-dialog"
  >
    <div class="app-container">
      <div class="avue-crud">
        <el-form
          :model="dataForm"
          :rules="dataRule"
          ref="dataForm"
          label-width="120px"
          class="l-mes"
        >
          <el-row>
            <el-col :span="20">
              <el-form-item label="车间" prop="workShop">
                <el-select
                  v-model="dataForm.workShop"
                  placeholder=""
                  style="width:100%"
                >
                  <el-option
                    v-for="item in workShopOptions"
                    :key="item.id"
                    :label="item.label"
                    :value="item.value"
                  >
                  </el-option>
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
        </el-form>
      </div>
    </div>
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" :disabled="isSubmit" v-thinclick="`submitTask`"
        >确 定</el-button
      >
    </div>
  </el-dialog>
</template>
<script>
import { submitOrderProduceTask } from '@/api/plan/segmentmerge'
import { remote } from '@/api/admin/dict'
export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    taskList: {
      type: Array,
      default: () => {
        return []
      }
    }
  },
  data() {
    return {
      innerVisible: false,
      dataForm: {
        workShop: null
      },
      dataRule: {
        workShop: [
          { required: true, message: '车间不能为空', trigger: 'change' }
        ]
      },
      isSubmit: false,
      workShopOptions: []
    }
  },
  created() {
    this.getWorkShopOptions()
  },
  methods: {
    getWorkShopOptions() {
      remote('work_shop').then((response) => {
        if (response.data.code === 0) {
          this.workShopOptions = response.data.data
        } else {
          this.workShopOptions = []
        }
      })
    },
    submitTask() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          const objArr = []
          this.taskList.forEach((item) => {
            objArr.push({
              id: item.id,
              partId: item.partId,
              mergeSnNo: item.mergeSnNo,
              routingOperations: item.routingOperations,
              workshop: this.dataForm.workShop
            })
          })
          submitOrderProduceTask(objArr).then((response) => {
            this.$message.success('提交成功!')
            this.$emit('refreshTaskList')
          })
          this.innerVisible = false
          this.isSubmit = false
        } else {
          this.isSubmit = false
        }
      })
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      this.dataForm.workShop = null
      if (this.currshowlist) {
        this.$nextTick(() => {
          //
        })
      }
    }
  },
  mounted() {}
}
</script>
<style scoped>
.generate-task-dialog >>> .el-dialog__body {
  padding: 10px 20px 10px 20px;
}
</style>
